module.exports = defineTest({
	description: 'handles conditionally thrown errors'
});
